chain_genesis

Function chain_genesis 

pub fn chain_genesis<H: Hash>(image: &Image) -> H::Out
where H::Out: From<[u8; 32]>,
Genesis image-hash chain: a freshly-derived Instance (with no prior chain) has image_hash = image_content_hash.

This is the case for the very first Instance the chain spec produces. Subsequent Instances always derive from some spawner via chain_extend.