pub struct WireCNodeCap {
pub size_log: u8,
pub slots: Vec<WireCNodeSlot>,
}Expand description
Wire form of CNodeCap. Flat list of (slot, hash) pairs;
only materialized Hash slot entries are carried.
Fields
size_log: u8slots: Vec<WireCNodeSlot>Trait Implementations
Sourceimpl Archive for WireCNodeCap
impl Archive for WireCNodeCap
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedWireCNodeCap
type Archived = ArchivedWireCNodeCap
The archived representation of this type. Read more
Sourcetype Resolver = WireCNodeCapResolver
type Resolver = WireCNodeCapResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for WireCNodeCap
impl Clone for WireCNodeCap
Sourcefn clone(&self) -> WireCNodeCap
fn clone(&self) -> WireCNodeCap
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WireCNodeCap
impl Debug for WireCNodeCap
Sourceimpl<__D: Fallible + ?Sized> Deserialize<WireCNodeCap, __D> for Archived<WireCNodeCap>where
u8: Archive,
<u8 as Archive>::Archived: Deserialize<u8, __D>,
Vec<WireCNodeSlot>: Archive,
<Vec<WireCNodeSlot> as Archive>::Archived: Deserialize<Vec<WireCNodeSlot>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<WireCNodeCap, __D> for Archived<WireCNodeCap>where
u8: Archive,
<u8 as Archive>::Archived: Deserialize<u8, __D>,
Vec<WireCNodeSlot>: Archive,
<Vec<WireCNodeSlot> as Archive>::Archived: Deserialize<Vec<WireCNodeSlot>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<WireCNodeCap, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<WireCNodeCap, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for WireCNodeCap
impl<__S: Fallible + ?Sized> Serialize<__S> for WireCNodeCap