pub struct WireCNodeSlot {
pub slot: u32,
pub cap_hash: [u8; 32],
}Fields
slot: u32cap_hash: [u8; 32]Trait Implementations
Sourceimpl Archive for WireCNodeSlot
impl Archive for WireCNodeSlot
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedWireCNodeSlot
type Archived = ArchivedWireCNodeSlot
The archived representation of this type. Read more
Sourcetype Resolver = WireCNodeSlotResolver
type Resolver = WireCNodeSlotResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for WireCNodeSlot
impl Clone for WireCNodeSlot
Sourcefn clone(&self) -> WireCNodeSlot
fn clone(&self) -> WireCNodeSlot
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WireCNodeSlot
impl Debug for WireCNodeSlot
Sourceimpl<__D: Fallible + ?Sized> Deserialize<WireCNodeSlot, __D> for Archived<WireCNodeSlot>
impl<__D: Fallible + ?Sized> Deserialize<WireCNodeSlot, __D> for Archived<WireCNodeSlot>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<WireCNodeSlot, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<WireCNodeSlot, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for WireCNodeSlot
impl<__S: Fallible + ?Sized> Serialize<__S> for WireCNodeSlot