pub struct WireDataCap {
pub bytes: Vec<u8>,
}Expand description
Wire form of DataCap. V0: inline-only.
Fields
bytes: Vec<u8>Trait Implementations
Sourceimpl Archive for WireDataCap
impl Archive for WireDataCap
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedWireDataCap
type Archived = ArchivedWireDataCap
The archived representation of this type. Read more
Sourcetype Resolver = WireDataCapResolver
type Resolver = WireDataCapResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for WireDataCap
impl Clone for WireDataCap
Sourcefn clone(&self) -> WireDataCap
fn clone(&self) -> WireDataCap
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WireDataCap
impl Debug for WireDataCap
Sourceimpl<__D: Fallible + ?Sized> Deserialize<WireDataCap, __D> for Archived<WireDataCap>
impl<__D: Fallible + ?Sized> Deserialize<WireDataCap, __D> for Archived<WireDataCap>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<WireDataCap, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<WireDataCap, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for WireDataCap
impl<__S: Fallible + ?Sized> Serialize<__S> for WireDataCap