pub struct WireEndpointDef {
pub entry_pc: u64,
pub stack_top: u64,
pub arg_cnode_slot: u32,
pub arg_cnode_size: u8,
pub initial_regs: [u64; 13],
}Fields
entry_pc: u64stack_top: u64arg_cnode_slot: u32arg_cnode_size: u8initial_regs: [u64; 13]Trait Implementations
Sourceimpl Archive for WireEndpointDef
impl Archive for WireEndpointDef
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedWireEndpointDef
type Archived = ArchivedWireEndpointDef
The archived representation of this type. Read more
Sourcetype Resolver = WireEndpointDefResolver
type Resolver = WireEndpointDefResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for WireEndpointDef
impl Clone for WireEndpointDef
Sourcefn clone(&self) -> WireEndpointDef
fn clone(&self) -> WireEndpointDef
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WireEndpointDef
impl Debug for WireEndpointDef
Sourceimpl<__D: Fallible + ?Sized> Deserialize<WireEndpointDef, __D> for Archived<WireEndpointDef>
impl<__D: Fallible + ?Sized> Deserialize<WireEndpointDef, __D> for Archived<WireEndpointDef>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<WireEndpointDef, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<WireEndpointDef, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for WireEndpointDef
impl<__S: Fallible + ?Sized> Serialize<__S> for WireEndpointDef