pub struct WireImageCap {
pub code: Vec<u8>,
pub bitmask: Vec<u8>,
pub jump_table: Vec<u32>,
pub endpoints: Vec<WireEndpointDef>,
pub mappings: Vec<WireMemoryMapping>,
pub pinned: Vec<WireImageSlotEntry>,
pub initial: Vec<WireImageSlotEntry>,
pub yield_marker_slot: Option<u32>,
}Expand description
Wire form of ImageCap. Direct field-for-field mirror — all
inner types are derive-compatible already.
Fields
code: Vec<u8>bitmask: Vec<u8>jump_table: Vec<u32>endpoints: Vec<WireEndpointDef>mappings: Vec<WireMemoryMapping>pinned: Vec<WireImageSlotEntry>initial: Vec<WireImageSlotEntry>yield_marker_slot: Option<u32>Trait Implementations
Sourceimpl Archive for WireImageCapwhere
Vec<u8>: Archive,
Vec<u32>: Archive,
Vec<WireEndpointDef>: Archive,
Vec<WireMemoryMapping>: Archive,
Vec<WireImageSlotEntry>: Archive,
Option<u32>: Archive,
impl Archive for WireImageCapwhere
Vec<u8>: Archive,
Vec<u32>: Archive,
Vec<WireEndpointDef>: Archive,
Vec<WireMemoryMapping>: Archive,
Vec<WireImageSlotEntry>: Archive,
Option<u32>: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedWireImageCap
type Archived = ArchivedWireImageCap
The archived representation of this type. Read more
Sourcetype Resolver = WireImageCapResolver
type Resolver = WireImageCapResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for WireImageCap
impl Clone for WireImageCap
Sourcefn clone(&self) -> WireImageCap
fn clone(&self) -> WireImageCap
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WireImageCap
impl Debug for WireImageCap
Sourceimpl<__D: Fallible + ?Sized> Deserialize<WireImageCap, __D> for Archived<WireImageCap>where
Vec<u8>: Archive,
<Vec<u8> as Archive>::Archived: Deserialize<Vec<u8>, __D>,
Vec<u32>: Archive,
<Vec<u32> as Archive>::Archived: Deserialize<Vec<u32>, __D>,
Vec<WireEndpointDef>: Archive,
<Vec<WireEndpointDef> as Archive>::Archived: Deserialize<Vec<WireEndpointDef>, __D>,
Vec<WireMemoryMapping>: Archive,
<Vec<WireMemoryMapping> as Archive>::Archived: Deserialize<Vec<WireMemoryMapping>, __D>,
Vec<WireImageSlotEntry>: Archive,
<Vec<WireImageSlotEntry> as Archive>::Archived: Deserialize<Vec<WireImageSlotEntry>, __D>,
Option<u32>: Archive,
<Option<u32> as Archive>::Archived: Deserialize<Option<u32>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<WireImageCap, __D> for Archived<WireImageCap>where
Vec<u8>: Archive,
<Vec<u8> as Archive>::Archived: Deserialize<Vec<u8>, __D>,
Vec<u32>: Archive,
<Vec<u32> as Archive>::Archived: Deserialize<Vec<u32>, __D>,
Vec<WireEndpointDef>: Archive,
<Vec<WireEndpointDef> as Archive>::Archived: Deserialize<Vec<WireEndpointDef>, __D>,
Vec<WireMemoryMapping>: Archive,
<Vec<WireMemoryMapping> as Archive>::Archived: Deserialize<Vec<WireMemoryMapping>, __D>,
Vec<WireImageSlotEntry>: Archive,
<Vec<WireImageSlotEntry> as Archive>::Archived: Deserialize<Vec<WireImageSlotEntry>, __D>,
Option<u32>: Archive,
<Option<u32> as Archive>::Archived: Deserialize<Option<u32>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<WireImageCap, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<WireImageCap, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for WireImageCapwhere
Vec<u8>: Serialize<__S>,
Vec<u32>: Serialize<__S>,
Vec<WireEndpointDef>: Serialize<__S>,
Vec<WireMemoryMapping>: Serialize<__S>,
Vec<WireImageSlotEntry>: Serialize<__S>,
Option<u32>: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for WireImageCapwhere
Vec<u8>: Serialize<__S>,
Vec<u32>: Serialize<__S>,
Vec<WireEndpointDef>: Serialize<__S>,
Vec<WireMemoryMapping>: Serialize<__S>,
Vec<WireImageSlotEntry>: Serialize<__S>,
Option<u32>: Serialize<__S>,