pub struct WireImageSlotEntry {
pub slot: u32,
pub cap_hash: [u8; 32],
}Fields
slot: u32cap_hash: [u8; 32]Trait Implementations
Sourceimpl Archive for WireImageSlotEntry
impl Archive for WireImageSlotEntry
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedWireImageSlotEntry
type Archived = ArchivedWireImageSlotEntry
The archived representation of this type. Read more
Sourcetype Resolver = WireImageSlotEntryResolver
type Resolver = WireImageSlotEntryResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for WireImageSlotEntry
impl Clone for WireImageSlotEntry
Sourcefn clone(&self) -> WireImageSlotEntry
fn clone(&self) -> WireImageSlotEntry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WireImageSlotEntry
impl Debug for WireImageSlotEntry
Sourceimpl<__D: Fallible + ?Sized> Deserialize<WireImageSlotEntry, __D> for Archived<WireImageSlotEntry>
impl<__D: Fallible + ?Sized> Deserialize<WireImageSlotEntry, __D> for Archived<WireImageSlotEntry>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<WireImageSlotEntry, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<WireImageSlotEntry, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for WireImageSlotEntry
impl<__S: Fallible + ?Sized> Serialize<__S> for WireImageSlotEntry