pub struct WireInstanceCap {
pub image_hash_chain: [u8; 32],
pub image_hash: [u8; 32],
pub root_cnode_hash: [u8; 32],
pub rw_overlays: Vec<WireRwOverlay>,
pub mem_size: u32,
pub regs: [u64; 13],
pub pc: u64,
pub gas_remaining: u64,
}Expand description
Wire form of InstanceCap. root_cnode collapses
CapHashOrRef down to a plain hash (V0: refs unsupported).
Fields
image_hash_chain: [u8; 32]image_hash: [u8; 32]root_cnode_hash: [u8; 32]rw_overlays: Vec<WireRwOverlay>mem_size: u32regs: [u64; 13]pc: u64gas_remaining: u64Trait Implementations
Sourceimpl Archive for WireInstanceCap
impl Archive for WireInstanceCap
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedWireInstanceCap
type Archived = ArchivedWireInstanceCap
The archived representation of this type. Read more
Sourcetype Resolver = WireInstanceCapResolver
type Resolver = WireInstanceCapResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for WireInstanceCap
impl Clone for WireInstanceCap
Sourcefn clone(&self) -> WireInstanceCap
fn clone(&self) -> WireInstanceCap
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WireInstanceCap
impl Debug for WireInstanceCap
Sourceimpl<__D: Fallible + ?Sized> Deserialize<WireInstanceCap, __D> for Archived<WireInstanceCap>where
[u8; 32]: Archive,
<[u8; 32] as Archive>::Archived: Deserialize<[u8; 32], __D>,
Vec<WireRwOverlay>: Archive,
<Vec<WireRwOverlay> as Archive>::Archived: Deserialize<Vec<WireRwOverlay>, __D>,
u32: Archive,
<u32 as Archive>::Archived: Deserialize<u32, __D>,
[u64; 13]: Archive,
<[u64; 13] as Archive>::Archived: Deserialize<[u64; 13], __D>,
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
impl<__D: Fallible + ?Sized> Deserialize<WireInstanceCap, __D> for Archived<WireInstanceCap>where
[u8; 32]: Archive,
<[u8; 32] as Archive>::Archived: Deserialize<[u8; 32], __D>,
Vec<WireRwOverlay>: Archive,
<Vec<WireRwOverlay> as Archive>::Archived: Deserialize<Vec<WireRwOverlay>, __D>,
u32: Archive,
<u32 as Archive>::Archived: Deserialize<u32, __D>,
[u64; 13]: Archive,
<[u64; 13] as Archive>::Archived: Deserialize<[u64; 13], __D>,
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<WireInstanceCap, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<WireInstanceCap, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for WireInstanceCap
impl<__S: Fallible + ?Sized> Serialize<__S> for WireInstanceCap