pub struct WireMemoryMapping {
pub start: u64,
pub size: u64,
pub source_path: Vec<u32>,
pub source_path_len: u8,
}Fields
start: u64size: u64source_path: Vec<u32>source_path_len: u8Trait Implementations
Sourceimpl Archive for WireMemoryMapping
impl Archive for WireMemoryMapping
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedWireMemoryMapping
type Archived = ArchivedWireMemoryMapping
The archived representation of this type. Read more
Sourcetype Resolver = WireMemoryMappingResolver
type Resolver = WireMemoryMappingResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for WireMemoryMapping
impl Clone for WireMemoryMapping
Sourcefn clone(&self) -> WireMemoryMapping
fn clone(&self) -> WireMemoryMapping
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WireMemoryMapping
impl Debug for WireMemoryMapping
Sourceimpl<__D: Fallible + ?Sized> Deserialize<WireMemoryMapping, __D> for Archived<WireMemoryMapping>
impl<__D: Fallible + ?Sized> Deserialize<WireMemoryMapping, __D> for Archived<WireMemoryMapping>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<WireMemoryMapping, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<WireMemoryMapping, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for WireMemoryMapping
impl<__S: Fallible + ?Sized> Serialize<__S> for WireMemoryMapping