pub struct WireTypeCap {
pub image_hash_chain: [u8; 32],
}Fields
image_hash_chain: [u8; 32]Trait Implementations
Sourceimpl Archive for WireTypeCap
impl Archive for WireTypeCap
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedWireTypeCap
type Archived = ArchivedWireTypeCap
The archived representation of this type. Read more
Sourcetype Resolver = WireTypeCapResolver
type Resolver = WireTypeCapResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for WireTypeCap
impl Clone for WireTypeCap
Sourcefn clone(&self) -> WireTypeCap
fn clone(&self) -> WireTypeCap
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WireTypeCap
impl Debug for WireTypeCap
Sourceimpl<__D: Fallible + ?Sized> Deserialize<WireTypeCap, __D> for Archived<WireTypeCap>
impl<__D: Fallible + ?Sized> Deserialize<WireTypeCap, __D> for Archived<WireTypeCap>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<WireTypeCap, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<WireTypeCap, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for WireTypeCap
impl<__S: Fallible + ?Sized> Serialize<__S> for WireTypeCap