pub struct SlotPath {
pub steps: Vec<SlotIdx>,
}Expand description
Path from the root cnode through nested cnodes to a slot.
steps is the sequence of slot indices walked through nested
Cap::CNode slots; the final step’s slot is the target. An
empty steps is invalid (must address some slot).
Example: SlotPath { steps: vec![SlotIdx(7)] } addresses
slot 7 of the root cnode. SlotPath { steps: vec![SlotIdx(7), SlotIdx(3)] } addresses slot 3 of the Cap::CNode held in
root slot 7.
Fields
steps: Vec<SlotIdx>Implementations
Sourceimpl SlotPath
impl SlotPath
Sourcepub fn new(steps: Vec<SlotIdx>) -> Result<Self, CapError>
pub fn new(steps: Vec<SlotIdx>) -> Result<Self, CapError>
Construct from a list of steps. Returns Err if empty.
Sourcepub fn is_root_slot(&self) -> bool
pub fn is_root_slot(&self) -> bool
True iff this path has exactly one step (i.e., addresses a slot in the root cnode, not nested).